@@ -3,6 +3,7 @@
 
 import logging
 from Queue import Queue, LifoQueue
+from collections import defaultdict
 
 import tornado.web
 from tornado.httpclient import AsyncHTTPClient
@@ -59,9 +60,9 @@ def configure_app(self, config=None, log_level='INFO', debug=False, main_loop=No
     self.ignored_items = 0
 
     if self.config.PROCESS_NEWER_MESSAGES_FIRST:
-        self.items_to_process = LifoQueue()
+        self.items_to_process = defaultdict(LifoQueue)
     else:
-        self.items_to_process = Queue()
+        self.items_to_process = defaultdict(Queue)
 
     self.last_requests = []
     self.average_request_time = None
