@@ -37,17 +37,22 @@ class RouterHandler(BaseHandler):
 
         url = "%s%s?%s" % (self.application.config.SENTRY_BASE_URL, self.request.path, self.request.query)
 
-        if self.application.config.URL_CACHE_EXPIRATION > 0 and self.application.cache.get(url) is not None:
-            self.set_status(304)
-            self.set_header("X-CYCLOPS-IGNORED", "INVISIBLE")
-            self.application.ignored_items += 1
-            self.finish()
-            return
+        if self.application.config.URL_CACHE_EXPIRATION > 0:
+            if self.application.cache.get(url) is None:
+                self.application.cache.set(url, self.application.config.URL_CACHE_EXPIRATION)
 
+            count = self.application.cache.incr(url)
+            if count > self.application.config.MAX_CACHE_USES:
+                self.set_status(304)
+                self.set_header("X-CYCLOPS-CACHE-COUNT", str(count))
+                self.set_header("X-CYCLOPS-IGNORED", "INVISIBLE")
+                self.application.ignored_items += 1
+                self.finish()
+                return
+
+        self.set_header("X-CYCLOPS-CACHE-COUNT", str(count))
         self.set_header("X-CYCLOPS-IGNORED", "PROCESSED")
         self.application.processed_items += 1
-        if self.application.config.URL_CACHE_EXPIRATION > 0:
-            self.application.cache.set(url, self.application.config.URL_CACHE_EXPIRATION)
         self.process_request(project_id, url)
 
     @tornado.web.asynchronous
